@@ -684,6 +684,8 @@ ftp_connection_parse_features (FtpConnection *conn)
 	    }
 	}
     }
+  
+  g_strfreev (supported);
 }
 
 /* NB: you must free the connection if it's in error returning from here */
@@ -738,7 +740,7 @@ ftp_connection_login (FtpConnection *conn,
        *   problems with our client.
        * - we don't want to drown in spam.
        */
-      if (password == NULL)
+      if (password == NULL || password[0] == 0)
 	password = "gvfsd-ftp-" VERSION "@example.com";
       status = ftp_connection_send (conn, 0,
 				    "PASS %s", password);
@@ -999,6 +1001,9 @@ ftp_connection_close_data_connection (FtpConnection *conn)
  * make it easy to distinguish from GVfs paths.
  */
 
+#define ftp_filename_equal g_str_equal
+#define ftp_filename_copy(name) ((FtpFile *) g_strdup ((const char *) (name)))
+
 static FtpFile *
 ftp_filename_from_gvfs_path (FtpConnection *conn, const char *pathname)
 {
@@ -1026,7 +1031,25 @@ ftp_filename_construct (FtpConnection *conn, const FtpFile *dirname, const char
   return (FtpFile *) g_build_path ("/", (char *) dirname, basename, NULL);
 }
 
-#define ftp_filename_equal g_str_equal
+/* NB: returns the root directory for the root directory.
+ * Use ftp_filename_equal() afterwards to detect this */
+static FtpFile *
+ftp_filename_get_parent (FtpConnection *conn, const FtpFile *file)
+{
+  char *dirname, *filename;
+  FtpFile *dir;
+
+  filename = ftp_filename_to_gvfs_path (conn, file);
+  dirname = g_path_get_dirname (filename);
+  if (dirname[0] == '.' && dirname[1] == 0)
+    dir = ftp_filename_copy (file);
+  else
+    dir = ftp_filename_from_gvfs_path (conn, dirname);
+  g_free (filename);
+  g_free (dirname);
+
+  return dir;
+}
 
 /*** COMMON FUNCTIONS WITH SPECIAL HANDLING ***/
 
@@ -1676,6 +1699,32 @@ do_unmount (GVfsBackend *   backend,
   g_vfs_job_succeeded (G_VFS_JOB (job));
 }
 
+static void
+error_550_exists (FtpConnection *conn, const FtpFile *file)
+{
+  /* FIXME:
+   * What we should do here is look at the cache to figure out if the file 
+   * exists, but as cache access is currently only exposed via the backend
+   * structure (it should be properly abstracted into an opaque thread-safe
+   * structure and then be available per-connection), we cannot do that.
+   * So instead, we use the same code we use when trying to find hidden
+   * directories.
+   */
+  if (ftp_connection_try_cd (conn, file) ||
+      ftp_connection_send (conn, 0, "SIZE %s", file))
+    {
+      g_set_error_literal (&conn->error,
+                           G_IO_ERROR,
+                           G_IO_ERROR_EXISTS,
+                           _("Target file already exists"));
+    }
+  else
+    {
+      /* clear potential error from ftp_connection_send() in else if line above */
+      ftp_connection_clear_error (conn);
+    }
+}
+
 static void
 error_550_is_directory (FtpConnection *conn, const FtpFile *file)
 {
@@ -1691,6 +1740,21 @@ error_550_is_directory (FtpConnection *conn, const FtpFile *file)
     }
 }
 
+static void
+error_550_parent_not_found (FtpConnection *conn, const FtpFile *file)
+{
+  FtpFile *dir = ftp_filename_get_parent (conn, file);
+
+  if (!ftp_filename_equal (file, dir) && !ftp_connection_try_cd (conn, dir))
+    {
+      g_set_error_literal (&conn->error, G_IO_ERROR,
+                           G_IO_ERROR_NOT_FOUND,
+                           _("No such file or directory"));
+    }
+
+  g_free (dir);
+}
+
 static void
 do_open_for_read (GVfsBackend *backend,
 		  GVfsJobOpenForRead *job,
@@ -1817,18 +1881,12 @@ gvfs_backend_ftp_purge_cache_of_file (GVfsBackendFtp *ftp,
 				      FtpConnection * conn,
 				      const FtpFile * file)
 {
-  char *dirname, *filename;
-  FtpFile *dir;
+  FtpFile *dir = ftp_filename_get_parent (conn, file);
 
-  filename = ftp_filename_to_gvfs_path (conn, file);
-  dirname = g_path_get_dirname (filename);
-  dir = ftp_filename_from_gvfs_path (conn, dirname);
-
-  gvfs_backend_ftp_purge_cache_directory (ftp, dir);
+  if (!ftp_filename_equal (file, dir))
+    gvfs_backend_ftp_purge_cache_directory (ftp, dir);
 
   g_free (dir);
-  g_free (filename);
-  g_free (dirname);
 }
 
 /* forward declaration */
@@ -2140,6 +2198,52 @@ create_file_info (GVfsBackendFtp *ftp, FtpConnection *conn, const char *filename
     }
   ftp->dir_ops->iter_free (iter);
   g_static_rw_lock_reader_unlock (&ftp->directory_cache_lock);
+
+  /* try to find hidden file/directory */
+  if (info == NULL)
+    {
+      if (ftp_connection_try_cd (conn, file))
+        {
+          char *tmp;
+
+          info = g_file_info_new ();
+
+          tmp = g_path_get_basename (filename);
+          g_file_info_set_name (info, tmp);
+          g_free (tmp);
+
+          gvfs_file_info_populate_default (info, filename, G_FILE_TYPE_DIRECTORY);
+
+          g_file_info_set_is_hidden (info, TRUE);
+        }
+      else if (ftp_connection_send (conn, 0, "SIZE %s", file))
+        {
+          char *tmp;
+
+          info = g_file_info_new ();
+
+          tmp = g_path_get_basename (filename);
+          g_file_info_set_name (info, tmp);
+          g_free (tmp);
+
+          gvfs_file_info_populate_default (info, filename, G_FILE_TYPE_REGULAR);
+
+          g_file_info_set_size (info, strtoul (conn->read_buffer+4, NULL, 0));
+
+          g_file_info_set_is_hidden (info, TRUE);
+        }
+      else
+        {
+          /* clear error from ftp_connection_send() in else if line above */
+          ftp_connection_clear_error (conn);
+
+          /* note that there might still be a file/directory, we just have 
+           * no way to figure this out (in particular on ftp servers that 
+           * don't support SIZE.
+           * If you have ways to improve file detection, patches are welcome. */
+        }
+    }
+
   g_free (dir);
   g_free (file);
   return info;
@@ -2425,7 +2529,10 @@ do_delete (GVfsBackend *backend,
 				   g_strerror (ENOTEMPTY));
 	    }
 	  else
-	    ftp_connection_set_error_from_response (conn, response);
+            {
+              ftp_connection_clear_error (conn);
+              ftp_connection_set_error_from_response (conn, response);
+            }
 	}
       else if (STATUS_GROUP (response) == 5)
 	{
@@ -2446,15 +2553,19 @@ do_make_directory (GVfsBackend *backend,
   GVfsBackendFtp *ftp = G_VFS_BACKEND_FTP (backend);
   FtpConnection *conn;
   FtpFile *file;
+  static const Ftp550Handler make_directory_handlers[] = { error_550_exists, error_550_parent_not_found, NULL };
 
   conn = g_vfs_backend_ftp_pop_connection (ftp, G_VFS_JOB (job));
   if (conn == NULL)
     return;
 
   file = ftp_filename_from_gvfs_path (conn, filename);
-  ftp_connection_send (conn,
-		       0,
-		       "MKD %s", file);
+  ftp_connection_send_and_check (conn,
+                                 0,
+                                 make_directory_handlers,
+                                 file,
+                                 "MKD %s", file);
+
   /* FIXME: Compare created file with name from server result to be sure 
    * it's correct and otherwise fail. */
   gvfs_backend_ftp_purge_cache_of_file (ftp, conn, file);
