@@ -188,16 +188,35 @@ g_vfs_job_run (GVfsJob *job)
   GVfsJobClass *class;
 
   class = G_VFS_JOB_GET_CLASS (job);
+
+  /* Ensure that the job lives durint the whole
+   * lifetime of the call, as it may disappear when
+   * we call g_vfs_job_succeed/fail()
+   */
+  g_object_ref (job);
+  
   class->run (job);
+  
+  g_object_unref (job);
 }
 
 gboolean
 g_vfs_job_try (GVfsJob *job)
 {
   GVfsJobClass *class;
+  gboolean res;
 
   class = G_VFS_JOB_GET_CLASS (job);
-  return class->try (job);
+  
+  /* Ensure that the job lives during the whole
+   * lifetime of the call, as it may disappear when
+   * we call g_vfs_job_succeed/fail()
+   */
+  g_object_ref (job);
+  res = class->try (job);
+  g_object_unref (job);
+
+  return res;
 }
 
 void
@@ -228,24 +247,33 @@ g_vfs_job_failed (GVfsJob *job,
   va_list args;
   char *message;
 
+  va_start (args, format);
+  message = g_strdup_vprintf (format, args);
+  va_end (args);
+
+  g_vfs_job_failed_literal (job, domain, code, message);
+  g_free (message);
+}
+
+void
+g_vfs_job_failed_literal (GVfsJob *job,
+                          GQuark        domain,
+                          gint          code,
+                          const gchar  *message)
+{
   if (job->failed)
     return;
 
   job->failed = TRUE;
 
-  va_start (args, format);
-  message = g_strdup_vprintf (format, args);
-  va_end (args);
-
-  job->error = g_error_new (domain, code, message);
-  g_free (message);
+  job->error = g_error_new_literal (domain, code, message);
 
   g_vfs_job_send_reply (job);
 }
 
 void
-g_vfs_job_failed_from_error (GVfsJob *job,
-			     GError *error)
+g_vfs_job_failed_from_error (GVfsJob *     job,
+			     const GError *error)
 {
   if (job->failed)
     return;
@@ -261,9 +289,9 @@ g_vfs_job_failed_from_errno (GVfsJob     *job,
 {
   GError *error = NULL;
   
-  g_set_error (&error, G_IO_ERROR,
-	       g_io_error_from_errno (errno_arg),
-	       "%s", g_strerror (errno_arg));
+  g_set_error_literal (&error, G_IO_ERROR,
+		       g_io_error_from_errno (errno_arg),
+		       g_strerror (errno_arg));
   g_vfs_job_failed_from_error (job, error);
   g_error_free (error);
 }
